==> poodio-0.0.21.tar.gz: poodio-0.0.21/poodio/README.md <==
# _**poodio**_

[![Stars](https://img.shields.io/github/stars/AsherJingkongChen/poopoo?style=for-the-badge&label=stars&logo=refinedgithub&logoColor=fff&labelColor=333&color=c83)](https://github.com/AsherJingkongChen/poopoo/stargazers)
[![Issues](https://img.shields.io/github/issues/AsherJingkongChen/poopoo?style=for-the-badge&label=issues&logo=github&logoColor=fff&labelColor=333&color=485)](https://github.com/AsherJingkongChen/poopoo/issues)
[![Version](https://img.shields.io/github/v/release/AsherJingkongChen/poopoo?filter=poodio%40*&style=for-the-badge&label=version&logo=semver&logoColor=fff&labelColor=333&color=38c)](https://github.com/AsherJingkongChen/poopoo/releases?q=poodio&expanded=true)
[![License](https://img.shields.io/github/license/AsherJingkongChen/poopoo?style=for-the-badge&label=license&logo=spdx&logoColor=09f&labelColor=333&color=048)](https://github.com/AsherJingkongChen/poopoo/blob/main/LICENSE.txt)

💩 💨 Farts poo poo audio 💨 💩

## Install & Run

[![NpmJS.com](https://img.shields.io/npm/v/poodio?style=for-the-badge&label=npmjs&logo=npm&logoColor=d33&labelColor=333&color=c22)](https://www.npmjs.com/package/poodio)
[![PyPI.org](https://img.shields.io/pypi/v/poodio?style=for-the-badge&label=pypi&logo=pypi&logoColor=fd4&labelColor=333&color=59d)](https://pypi.org/project/poodio/)

💩 We provide several ways to install and run **`poodio`** on your system with a single command. 💩

1. **💩 [`bunx`](https://bun.sh/) 💩**
    ```shell
    bunx poodio
    ```
    ```shell
    bunx --bun poodio
    ```
    ```shell
    bunx poodio@0.1.0
    ```
2. **💩 [`npx`](https://nodejs.org/en/download/) 💩**
    ```shell
    npx -y poodio
    ```
    ```shell
    npx -y poodio@0.1.0
    ```
3. **💩 [`pipx`](https://pypi.org/project/pipx/) 💩**
    ```shell
    pipx run poodio
    ```
    ```shell
    pipx run poodio==0.1.0
    ```
4. **💩 [`uvx`](https://docs.astral.sh/uv/#installation) 💩**
    ```shell
    uvx poodio
    ```
    ```shell
    uvx poodio==0.1.0
    ```

## Install

[![NpmJS.com](https://img.shields.io/npm/v/poodio?style=for-the-badge&label=npmjs&logo=npm&logoColor=d33&labelColor=333&color=c22)](https://www.npmjs.com/package/poodio)
[![Crates.io](https://img.shields.io/crates/v/poodio?style=for-the-badge&label=crates&logo=docs.rs&logoColor=da3&labelColor=333&color=473)](https://crates.io/crates/poodio)
[![PyPI.org](https://img.shields.io/pypi/v/poodio?style=for-the-badge&label=pypi&logo=pypi&logoColor=fd4&labelColor=333&color=59d)](https://pypi.org/project/poodio/)

💩 We provide several ways to install **`poodio`** so you can [run](#run) it later. 💩

1. **💩 [`cargo-binstall`](https://github.com/cargo-bins/cargo-binstall?tab=readme-ov-file#installation) 💩**
    ```shell
    cargo-binstall -y poodio
    ```
    ```shell
    cargo-binstall -y poodio@0.1.0
    ```
2. **💩 [`npm`](https://nodejs.org/en/download/) 💩**
    ```shell
    npm i -g poodio
    ```
    ```shell
    npm i -g poodio@0.1.0
    ```
3. **💩 [`pip`](https://pip.pypa.io/en/stable/installation/) 💩**
    ```shell
    pip install poodio
    ```
    ```shell
    pip install poodio==0.1.0
    ```
4. **💩 [`uv`](https://docs.astral.sh/uv/#installation) 💩**
    ```shell
    uv tool install poodio
    ```
    ```shell
    uv tool install poodio==0.1.0
    ```
5. **💩 [`git`](https://git-scm.com/downloads) & [`cargo`](https://doc.rust-lang.org/cargo/getting-started/installation.html) 💩**
    ```shell
    git clone https://github.com/AsherJingkongChen/poopoo -b main --depth 1
    cargo install --path poopoo/poodio
    ```
    ```shell
    git clone https://github.com/AsherJingkongChen/poopoo -b poodio@0.1.0 --depth 1
    cargo install --path poopoo/poodio
    ```

## Run

[![CLI](https://img.shields.io/badge/cli-6a3?style=for-the-badge&logo=gnometerminal&logoColor=6a3&labelColor=333)](https://en.wikipedia.org/wiki/Command-line_interface)
[![Linux](https://img.shields.io/badge/linux-fc2?style=for-the-badge&logo=linux&logoColor=fc2&labelColor=333)](https://kernel.org/)
[![macOS](https://img.shields.io/badge/macos-eee?style=for-the-badge&logo=apple&logoColor=fff&labelColor=333)](https://www.apple.com/macos/)
[![Windows](https://img.shields.io/badge/windows-07d?style=for-the-badge&logo=gitforwindows&logoColor=07d&labelColor=333)](https://www.microsoft.com/en-us/windows/)
[![ARM64](https://img.shields.io/badge/arm64-09b?style=for-the-badge&logo=arm&logoColor=09b&labelColor=333)](https://www.kernel.org/doc/html/v6.14/arch/arm64/index.html)
[![x86-64](https://img.shields.io/badge/x86%e2%80%9364-e22?style=for-the-badge&logo=amd&logoColor=e22&labelColor=333)](https://www.kernel.org/doc/html/v6.14/arch/x86/x86_64/index.html)

💩 After [installing](#install), run **`poodio`** with the following commands. 💩

1. **💩 Prints help info 💩**
    ```shell
    poodio -h
    ```
    ```shell
    poodio --help
    ```
2. **💩 Prints version info 💩**
    ```shell
    poodio -V
    ```
    ```shell
    poodio --version
    ```

## Integrate

[![Rust](https://img.shields.io/crates/msrv/poodio?style=for-the-badge&label=rust&logo=rust&logoColor=fff&labelColor=333&color=d41)](https://crates.io/crates/poodio)
[![Node.js](https://img.shields.io/node/v/poodio?style=for-the-badge&label=node&logo=node.js&logoColor=6c3&labelColor=333&color=393)](https://www.npmjs.com/package/poodio)
[![Python](https://img.shields.io/python/required-version-toml?tomlFilePath=https%3A%2F%2Fraw.githubusercontent.com%2FAsherjingkongChen%2Fpoopoo%2Fmain%2Fpoodio%2Fpyproject.toml&style=for-the-badge&label=python&logo=python&logoColor=fd4&labelColor=333&color=36a)](https://pypi.org/project/poodio/)

💩 You can integrate **`poodio`** into your own project with the following commands. 💩

1. **💩 [`cargo`](https://doc.rust-lang.org/cargo/getting-started/installation.html) 💩**
    ```shell
    cargo add poodio
    ```
    ```shell
    cargo add poodio@0.1.0
    ```
2. **💩 [`npm`](https://nodejs.org/en/download/) 💩**
    ```shell
    npm i poodio
    ```
    ```shell
    npm i poodio@0.1.0
    ```
3. **💩 [`uv`](https://docs.astral.sh/uv/#installation) 💩**
    ```shell
    uv add poodio
    ```
    ```shell
    uv add poodio==0.1.0
    ```
4. **💩 [`git`](https://git-scm.com/downloads) & [`cargo`](https://doc.rust-lang.org/cargo/getting-started/installation.html) 💩**
    ```shell
    git clone https://github.com/AsherJingkongChen/poopoo -b main --depth 1
    cargo add --path poopoo/poodio
    ```
    ```shell
    git clone https://github.com/AsherJingkongChen/poopoo -b poodio@0.1.0 --depth 1
    cargo add --path poopoo/poodio
    ```

==> poodio-0.0.22.tar.gz: poodio-0.0.22/poodio/README.md <==
# _**poodio**_

[![Stars](https://img.shields.io/github/stars/AsherJingkongChen/poopoo?style=for-the-badge&label=stars&logo=refinedgithub&logoColor=fff&labelColor=333&color=c83)](https://github.com/AsherJingkongChen/poopoo/stargazers)
[![Issues](https://img.shields.io/github/issues/AsherJingkongChen/poopoo?style=for-the-badge&label=issues&logo=github&logoColor=fff&labelColor=333&color=485)](https://github.com/AsherJingkongChen/poopoo/issues)
[![Version](https://img.shields.io/github/v/release/AsherJingkongChen/poopoo?filter=poodio%40*&style=for-the-badge&label=version&logo=semver&logoColor=fff&labelColor=333&color=38c)](https://github.com/AsherJingkongChen/poopoo/releases?q=poodio%40&expanded=true)
[![License](https://img.shields.io/github/license/AsherJingkongChen/poopoo?style=for-the-badge&label=license&logo=spdx&logoColor=09f&labelColor=333&color=048)](https://github.com/AsherJingkongChen/poopoo/blob/main/LICENSE.txt)

💩 💨 Farts poo poo audio 💨 💩

## Install & Run

[![NpmJS.com](https://img.shields.io/npm/v/poodio?style=for-the-badge&label=npmjs&logo=npm&logoColor=d33&labelColor=333&color=c22)](https://www.npmjs.com/package/poodio)
[![PyPI.org](https://img.shields.io/pypi/v/poodio?style=for-the-badge&label=pypi&logo=pypi&logoColor=fd4&labelColor=333&color=59d)](https://pypi.org/project/poodio/)

💩 We provide several ways to install and run **`poodio`** on your system with a single command. 💩

1. **💩 [`bunx`](https://bun.sh/) 💩**
    ```shell
    bunx poodio
    ```
    ```shell
    bunx --bun poodio
    ```
    ```shell
    bunx poodio@0.1.0
    ```
2. **💩 [`npx`](https://nodejs.org/en/download/) 💩**
    ```shell
    npx -y poodio
    ```
    ```shell
    npx -y poodio@0.1.0
    ```
3. **💩 [`pipx`](https://pypi.org/project/pipx/) 💩**
    ```shell
    pipx run poodio
    ```
    ```shell
    pipx run poodio==0.1.0
    ```
4. **💩 [`uvx`](https://docs.astral.sh/uv/#installation) 💩**
    ```shell
    uvx poodio
    ```
    ```shell
    uvx poodio==0.1.0
    ```

## Install

[![NpmJS.com](https://img.shields.io/npm/v/poodio?style=for-the-badge&label=npmjs&logo=npm&logoColor=d33&labelColor=333&color=c22)](https://www.npmjs.com/package/poodio)
[![Homebrew](https://img.shields.io/badge/dynamic/regex?url=https%3A%2F%2Fraw.githubusercontent.com%2FAsherJingkongChen%2Fhomebrew--%2Frefs%2Fheads%2Fmain%2FFormula%2Fpoodio.rb&search=version%20%22%28%5B0-9%5D%2B.%5B0-9%5D%2B.%5B0-9%5D%2B%29%22&replace=v%241&style=for-the-badge&label=homebrew&logo=homebrew&logoColor=fc9&labelColor=333&color=b73)](https://github.com/AsherJingkongChen/homebrew--/blob/main/Formula/poodio.rb)
[![Crates.io](https://img.shields.io/crates/v/poodio?style=for-the-badge&label=crates&logo=docs.rs&logoColor=da3&labelColor=333&color=473)](https://crates.io/crates/poodio)
[![PyPI.org](https://img.shields.io/pypi/v/poodio?style=for-the-badge&label=pypi&logo=pypi&logoColor=fd4&labelColor=333&color=59d)](https://pypi.org/project/poodio/)

💩 We provide several ways to install **`poodio`** so you can [run](#run) it later. 💩

1. **💩 [`brew`](https://brew.sh/) 💩**
    ```shell
    brew install asherjingkongchen/-/poodio
    ```
2. **💩 [`cargo-binstall`](https://github.com/cargo-bins/cargo-binstall?tab=readme-ov-file#installation) 💩**
    ```shell
    cargo-binstall -y poodio
    ```
    ```shell
    cargo-binstall -y poodio@0.1.0
    ```
3. **💩 [`npm`](https://nodejs.org/en/download/) 💩**
    ```shell
    npm i -g poodio
    ```
    ```shell
    npm i -g poodio@0.1.0
    ```
4. **💩 [`pip`](https://pip.pypa.io/en/stable/installation/) 💩**
    ```shell
    pip install poodio
    ```
    ```shell
    pip install poodio==0.1.0
    ```
5. **💩 [`uv`](https://docs.astral.sh/uv/#installation) 💩**
    ```shell
    uv tool install poodio
    ```
    ```shell
    uv tool install poodio==0.1.0
    ```
6. **💩 [`git`](https://git-scm.com/downloads) & [`cargo`](https://doc.rust-lang.org/cargo/getting-started/installation.html) 💩**
    ```shell
    git clone https://github.com/AsherJingkongChen/poopoo -b main --depth 1
    cargo install --locked --path poopoo/poodio
    ```
    ```shell
    git clone https://github.com/AsherJingkongChen/poopoo -b poodio@0.1.0 --depth 1
    cargo install --locked --path poopoo/poodio
    ```

## Run

[![macOS](https://img.shields.io/badge/macos-eee?style=for-the-badge&logo=apple&logoColor=fff&labelColor=333)](https://www.apple.com/macos/)
[![x86-64](https://img.shields.io/badge/x86%e2%80%9364-e22?style=for-the-badge&logo=amd&logoColor=e22&labelColor=333)](https://www.kernel.org/doc/html/v6.14/arch/x86/x86_64/index.html)
[![Linux](https://img.shields.io/badge/linux-fc2?style=for-the-badge&logo=linux&logoColor=fc2&labelColor=333)](https://kernel.org/)
[![CLI](https://img.shields.io/badge/cli-6a3?style=for-the-badge&logo=gnometerminal&logoColor=6a3&labelColor=333)](https://en.wikipedia.org/wiki/Command-line_interface)
[![ARM64](https://img.shields.io/badge/arm64-09b?style=for-the-badge&logo=arm&logoColor=09b&labelColor=333)](https://www.kernel.org/doc/html/v6.14/arch/arm64/index.html)
[![Windows](https://img.shields.io/badge/windows-07d?style=for-the-badge&logo=gitforwindows&logoColor=07d&labelColor=333)](https://www.microsoft.com/en-us/windows/)

💩 After [installing](#install), run **`poodio`** with the following commands. 💩

1. **💩 Prints help info 💩**
    ```shell
    poodio -h
    ```
    ```shell
    poodio --help
    ```
2. **💩 Prints version info 💩**
    ```shell
    poodio -V
    ```
    ```shell
    poodio --version
    ```

## Integrate

[![Rust](https://img.shields.io/crates/msrv/poodio?style=for-the-badge&label=rust&logo=rust&logoColor=fff&labelColor=333&color=d41)](https://crates.io/crates/poodio)
[![Node.js](https://img.shields.io/node/v/poodio?style=for-the-badge&label=node&logo=node.js&logoColor=6c3&labelColor=333&color=393)](https://www.npmjs.com/package/poodio)
[![Python](https://img.shields.io/python/required-version-toml?tomlFilePath=https%3A%2F%2Fraw.githubusercontent.com%2FAsherjingkongChen%2Fpoopoo%2Fmain%2Fpoodio%2Fpyproject.toml&style=for-the-badge&label=python&logo=python&logoColor=fd4&labelColor=333&color=36a)](https://pypi.org/project/poodio/)

💩 You can integrate **`poodio`** into your own project with the following commands. 💩

1. **💩 [`cargo`](https://doc.rust-lang.org/cargo/getting-started/installation.html) 💩**
    ```shell
    cargo add poodio
    ```
    ```shell
    cargo add poodio@0.1.0
    ```
2. **💩 [`npm`](https://nodejs.org/en/download/) 💩**
    ```shell
    npm i poodio
    ```
    ```shell
    npm i poodio@0.1.0
    ```
3. **💩 [`uv`](https://docs.astral.sh/uv/#installation) 💩**
    ```shell
    uv add poodio
    ```
    ```shell
    uv add poodio==0.1.0
    ```
4. **💩 [`git`](https://git-scm.com/downloads) & [`cargo`](https://doc.rust-lang.org/cargo/getting-started/installation.html) 💩**
    ```shell
    git clone https://github.com/AsherJingkongChen/poopoo -b main --depth 1
    cargo add --path poopoo/poodio
    ```
    ```shell
    git clone https://github.com/AsherJingkongChen/poopoo -b poodio@0.1.0 --depth 1
    cargo add --path poopoo/poodio
    ```
